@@ -44,7 +44,7 @@ namespace KSysGuard
 	      tracerPidColumn = ttyColumn = ioprioClassColumn = ioprioColumn =
 	      vmURSSColumn = -1;
               usedMemory = freeMemory;}
-      ~Private() {;}
+      ~Private() {}
       QString host;
       QList<QByteArray> lastAnswer;
       QSet<long> pids;
@@ -93,11 +93,11 @@ void ProcessesRemote::setup() {
 
 long ProcessesRemote::getParentPid(long pid) {
     if(!d->processByPid.contains(pid)) {
-        qCDebug(LIBKSYSGUARD) << "Parent pid requested for pid that we do not have info on " << pid;
+        qCDebug(LIBKSYSGUARD_PROCESSCORE) << "Parent pid requested for pid that we do not have info on " << pid;
         return 0;
     }
     if(d->ppidColumn == -1) {
-        qCDebug(LIBKSYSGUARD) << "ppid column not known ";
+        qCDebug(LIBKSYSGUARD_PROCESSCORE) << "ppid column not known ";
         return 0;
     }
     return d->processByPid[pid].at(d->ppidColumn).toLong();
@@ -106,12 +106,12 @@ bool ProcessesRemote::updateProcessInfo( long pid, Process *process)
 {
     Q_CHECK_PTR(process);
     if(!d->processByPid.contains(pid)) {
-	qCDebug(LIBKSYSGUARD) << "update request for pid that we do not have info on " << pid;
+    qCDebug(LIBKSYSGUARD_PROCESSCORE) << "update request for pid that we do not have info on " << pid;
         return false;
     }
     QList<QByteArray> p = d->processByPid[pid];
 
-    if(d->nameColumn!= -1) process->setName(p.at(d->nameColumn));
+    if(d->nameColumn!= -1) process->setName(QString::fromUtf8(p.at(d->nameColumn)));
     if(d->uidColumn!= -1) process->setUid(p.at(d->uidColumn).toLong());
     if(d->gidColumn!= -1) process->setGid(p.at(d->gidColumn).toLong());
     if(d->statusColumn!= -1) {
@@ -166,16 +166,16 @@ QSet<long> ProcessesRemote::getAllPids( )
 
 bool ProcessesRemote::sendSignal(long pid, int sig) {
 	//TODO run the proper command for all these functions below
-    emit runCommand("kill " + QString::number(pid) + " " + QString::number(sig), (int)Kill);
+    emit runCommand(QStringLiteral("kill ") + QString::number(pid) + QStringLiteral(" ") + QString::number(sig), (int)Kill);
     return true;
 }
 bool ProcessesRemote::setNiceness(long pid, int priority) {
-    emit runCommand("setpriority " + QString::number(pid) + " " + QString::number(priority), (int)Renice);
+    emit runCommand(QStringLiteral("setpriority ") + QString::number(pid) + QStringLiteral(" ") + QString::number(priority), (int)Renice);
     return true;
 }
 
 bool ProcessesRemote::setIoNiceness(long pid, int priorityClass, int priority) {
-    emit runCommand("ionice " + QString::number(pid) + " " + QString::number(priorityClass) + " " + QString::number(priority), (int)Ionice);
+    emit runCommand(QStringLiteral("ionice ") + QString::number(pid) + QStringLiteral(" ") + QString::number(priorityClass) + QStringLiteral(" ") + QString::number(priority), (int)Ionice);
     return true;
 }
 
